#
# spec file for package php7-redis
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org
#

%define php_name    php7
%define pkg_name    redis
Name:           %{php_name}-%{pkg_name}
Version:        4.0.2
Release:        lp150.1.1
Summary:        API for communicating with Redis servers
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/%{pkg_name}
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        %{pkg_name}.ini
BuildRequires:  %{php_name}-devel >= 7.0.1
BuildRequires:  %{php_name}-soap
BuildRequires:  re2c
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}

%description
This extension provides an API for communicating with Redis servers

%prep
%setup -q -n %{pkg_name}-%{version}

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{_bindir}/phpize
%configure
make %{?_smp_mflags}

%check
make %{?_smp_mflags} PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%install
make DESTDIR=%{buildroot} install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/%{php_name}/conf.d
install -m644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{php_name}/conf.d/%{pkg_name}.ini

%files
%defattr(0644,root,root,-)
%license COPYING
%doc CREDITS README.markdown
%config(noreplace) %{_sysconfdir}/%{php_name}/conf.d/%{pkg_name}.ini
%{_libdir}/%{php_name}/extensions/%{pkg_name}.so

%changelog
* Fri Apr 27 2018 ilya@ilya.pp.ua
- Update to 4.0.2
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.0.2
  * Fix of exists method to take multiple keys and return integer value.
* Fri Apr 20 2018 jweberhofer@weberhofer.at
- Update to 4.0.1
  * Fix arginfo for connect/pconnect issue
  * Don't leak a ZVAL
  * Fix config.m4 for lzf
  * Updates EXISTS documentation and notes change in 4.0.0
  * Fix typo in notes
* Mon Mar 19 2018 ilya@ilya.pp.ua
- Update to 4.0.0
  * https://pecl.php.net/package-changelog.php?package=redis&release=4.0.0
  * Add proper ARGINFO for all methods.
  * Let EXISTS take multiple keys.
  * Use zend_string as returning value for ra_extract_key and ra_call_extractor.
  * Implement SWAPDB and UNLINK commands.
  * Return real connection error as exception.
  * Disallow using empty string as session name.
  * Use zend_string for storing auth and prefix members.
  * The element of z_seeds may be a reference on php7.
  * Avoid connection in helper methods.
  * Add tcp_keepalive option to redis sock.
  * More robust GEORADIUS COUNT validation.
  * Add LZF compression (experimental).
  * Allow to use empty string as persistant_id.
  * Don't use convert_to_string in redis_hmget_cmd.
  * Allow mixing MULTI and PIPELINE modes (experimental).
  * PHP >=7.3.0 uses zend_string to store `php_url` elements.
  * Documentation improvements.
* Thu Mar  8 2018 ilya@ilya.pp.ua
- Remove %%configure/make duplicates.
- Add %%licence macros.
* Tue Jan 30 2018 crrodriguez@opensuse.org
- Build with hidden visibility, only a few symbols must be
  exported, those are marked with default visibility in PHP core
  headers.
* Thu Jan  4 2018 ilya@ilya.pp.ua
- Update to 3.1.6
  * ChangeLog https://pecl.php.net/package-changelog.php?package=redis&release=3.1.6
  * Fix of RedisArray distributor hashing function which was broken in 3.1.4.
  * Fix RedisCluster constructor with PHP 7 strict scalar type.
  * Allow to use empty string as persistant_id.
  * Fix cluster_init_seeds.
  * Fix z_seeds may be a reference.
  * PHP >=7.3 uses zend_string for php_url elements.
* Sun Oct  8 2017 ilya@ilya.pp.ua
- Update to 3.1.4
  * ChangeLog https://pecl.php.net/package-changelog.php?package=redis&release=3.1.4
  * Allow mixing MULTI and PIPELINE modes (experimental).
  * Added integration for coverty static analysis and fixed several warnings.
  * Fixed link to redis cluster documentation.
  * Remove unused PHP_RINIT and PHP_RSHUTDOWN functions.
  * Removed duplicate HGET in redis array hash table, formatting.
  * Treat NULL bulk as success for session read.
  * Refactor redis_send_discard.
  * Updated runtime exception handling.
  * Added a github issue template.
  * Initialize gc member of zend_string.
  * Fix valgrind warnings.
  * Fix php5/php7 compatibility layer.
  * Fix typo in README.markdown.
  * Improve redis array rehash.
  * Change redis array pure_cmds from zval to hashtable.
  * Don't try to set TCP_NODELAY on a unix socket and don't warn on multiple calls to pipeline.
  * Use zend_string rather than char* for various context fields.
  * Various other library fixes.
* Wed Aug  2 2017 tchvatal@suse.com
- Remove the php5 packages as the php5 language is being removed
* Wed Jul 19 2017 ilya@ilya.pp.ua
- Update to 3.1.3
  * ChangeLog https://pecl.php.net/package-changelog.php?package=redis&release=3.1.3
* Mon Jul 10 2017 ilya@ilya.pp.ua
- Add config file redis.ini
- Format spec-file to macro style
* Tue Jun 27 2017 jweberhofer@weberhofer.at
- Upgraded to version 3.1.2
  * RedisArray segfault fix [564ce3] (Pavlo Yatsukhnenko)
  * Small memory leak fix [645888b] (Mike Grunder)
  * Segfault fix when recreating RedisCluster objects [abf7d4] (Michael Grunder)
  * Fix for RedisCluster bulk response parsing [4121c4] (Alberto Fern?ndez)
  * Re allow single array for sInterStore [6ef0c2, d01966] (Michael Grunder)
  * Better TravisCI integration [4fd2f6] (Pavlo Yatsukhnenko)
* Sat Feb 18 2017 jweberhofer@weberhofer.at
- Upgraded to version 3.1.1
  This release contains mostly fixes for issues introduced when merging
  the php 5 and 7 codebase into a single branch.
  * Fixed a segfault in igbinary serialization (@yatsukhnenko)
  * Restore 2.2.8/3.0.0 functionality to distinguish between an error
    and simply empty session data. (@remicollet)
  * Fix double to string conversion function (@yatsukhnenko)
  * Use PHP_FE_END definition when available (@remicollet)
  * Fixed various 'static function declared but not used' warnings
  * Fixes to various calls which were typecasting pointers to the wrong size. (@remicollet)
  * Additional test updates for 32 bit systems (@remicollet)
  * ARM rounding issue in tests (@remicollet)
  * Use new zend_list_close instead of zend_list_delete when reconnecting.
  * Refactoring of redis_boolean_response_impl and redis_sock_write (@yatsukhnenko)
  * Added php session unit test (@yatsukhnenko)
  * Added explicit module dependancy for igbinary (@remicollet)
  * Added phpinfo serialization information (@remicollet)
- Version 3.1.0
  In this version of phpredis codebase was unified to work with all versions of php.
  Also many bug fixes and some improvements has been made.
- Improvements
  * Support the client to Redis Cluster just having one master (andyli) [892e5646]
  * Allow both long and strings that are longs for zrangebyscore offset/limit (Michael Grunder) [bdcdd2aa]
  * Process NX|XX, CH and INCR options in zAdd command (Pavlo Yatsukhnenko) [71c9f7c8]
- Fixes
  * Fix incrby/decrby for large integers (Michael Grunder) [3a12758a]
  * Use static declarations for spl_ce_RuntimeException decl (Jeremy Mikola) [a9857d69]
  * Fixed method call problem causes session handler to display two times (ZiHang Gao) [24f86c49]
  * psetex method returns '+OK' on success, not true (sitri@ndxbn) [afcd8445]
  * Fix integer overflow for long (>32bit) increments in hIncrBy (iyesin) [58e1d799]
  * Move zend_object handler to the end (Michael Grunder) [34107966]
  * Using setOption on redis array causes immediate connection (Pavlo Yatsukhnenko) [f1a85b38]
* Sun Jan 29 2017 jweberhofer@weberhofer.at
- Provide php-redis as php5 and php7 can't be installed together
* Tue Jan 10 2017 jweberhofer@weberhofer.at
- Updated to version 3.0.0 - no changelog provided
* Tue Mar  8 2016 danimo@owncloud.com
- Update build from php7 branch
